#!/bin/bash

# Remove results from the previous run
for OLDFILE in 00_Results.txt *.dat *.eps *.gnuplot *.png ;do
 if [ -f $OLDFILE ];then
  rm -f $OLDFILE
 fi
done

for ORBITRESULTS in source_visibility_prediction__*__*.txt ;do
# ORBITNAME=`echo $ORBITRESULTS | awk '{print $4}' FS='__'`
 ORBITNAME=`echo $ORBITRESULTS | awk '{print $3}' FS='__' | awk '{print $1}' FS='.'`
 ORBITTIME=`echo $ORBITRESULTS | awk '{print $2}' FS='__'`

 echo "Processing $ORBITNAME ..."

 # No filtering on baseline 
 OBSERVING_OPPORTUNITIES=`cat $ORBITRESULTS | grep -e Ef -e Gb -e At | wc -l`
 OBSERVING_WINDOWS=`cat $ORBITRESULTS | grep -e Ef -e Gb -e At | awk '{print $1}' | sort -n | uniq | wc -l`
 OBSERVING_WINDOWS_EF=`cat $ORBITRESULTS | grep -e Ef -e Gb -e At | grep Ef | awk '{print $1}' | sort -n | uniq | wc -l`
 OBSERVING_WINDOWS_GB=`cat $ORBITRESULTS | grep -e Ef -e Gb -e At | grep Gb | awk '{print $1}' | sort -n | uniq | wc -l`
 OBSERVING_WINDOWS_AT=`cat $ORBITRESULTS | grep -e Ef -e Gb -e At | grep At | awk '{print $1}' | sort -n | uniq | wc -l`
 OBSERVABLE_SOURCES=`cat $ORBITRESULTS | grep -e Ef -e Gb -e At | awk '{print $4}' | sort | uniq | wc -l`
 BASEINE_STATS=`cat $ORBITRESULTS | grep -e Ef -e Gb -e At | awk '{print $5}' |histsred7 | grep -v -e "MEAN_ERR" -e "sigma" -e "MAX-MIN"`
 
 # Short baselines for imaging
 SHORTBASE_OBSERVING_OPPORTUNITIES=`cat $ORBITRESULTS | grep -e Ef -e Gb -e At | awk '{if ( $5 < 2.0 ) print }' | wc -l`
 SHORTBASE_OBSERVING_WINDOWS=`cat $ORBITRESULTS | grep -e Ef -e Gb -e At | awk '{if ( $5 < 2.0 ) print }' | awk '{print $1}' | sort -n | uniq | wc -l`
 SHORTBASE_OBSERVING_WINDOWS_EF=`cat $ORBITRESULTS | grep -e Ef -e Gb -e At | awk '{if ( $5 < 2.0 ) print }' | grep Ef | awk '{print $1}' | sort -n | uniq | wc -l`
 SHORTBASE_OBSERVING_WINDOWS_GB=`cat $ORBITRESULTS | grep -e Ef -e Gb -e At | awk '{if ( $5 < 2.0 ) print }' | grep Gb | awk '{print $1}' | sort -n | uniq | wc -l`
 SHORTBASE_OBSERVING_WINDOWS_AT=`cat $ORBITRESULTS | grep -e Ef -e Gb -e At | awk '{if ( $5 < 2.0 ) print }' | grep At | awk '{print $1}' | sort -n | uniq | wc -l`
 SHORTBASE_OBSERVABLE_SOURCES=`cat $ORBITRESULTS | grep -e Ef -e Gb -e At | awk '{if ( $5 < 2.0 ) print }' | awk '{print $4}' | sort | uniq | wc -l`
 
 # Long baselines for records
 LONGBASE_OBSERVING_OPPORTUNITIES=`cat $ORBITRESULTS | grep -e Ef -e Gb -e At | awk '{if ( $5 > 25.0 ) print }' | wc -l`
 LONGBASE_OBSERVING_WINDOWS=`cat $ORBITRESULTS | grep -e Ef -e Gb -e At | awk '{if ( $5 > 25.0 ) print }' | awk '{print $1}' | sort -n | uniq | wc -l`
 LONGBASE_OBSERVING_WINDOWS_EF=`cat $ORBITRESULTS | grep -e Ef -e Gb -e At | awk '{if ( $5 > 25.0 ) print }' | grep Ef | awk '{print $1}' | sort -n | uniq | wc -l`
 LONGBASE_OBSERVING_WINDOWS_GB=`cat $ORBITRESULTS | grep -e Ef -e Gb -e At | awk '{if ( $5 > 25.0 ) print }' | grep Gb | awk '{print $1}' | sort -n | uniq | wc -l`
 LONGBASE_OBSERVING_WINDOWS_AT=`cat $ORBITRESULTS | grep -e Ef -e Gb -e At | awk '{if ( $5 > 25.0 ) print }' | grep At | awk '{print $1}' | sort -n | uniq | wc -l`
 LONGBASE_OBSERVABLE_SOURCES=`cat $ORBITRESULTS | grep -e Ef -e Gb -e At | awk '{if ( $5 > 25.0 ) print }' | awk '{print $4}' | sort | uniq | wc -l`
 
 echo " ####### Orbit $ORBITNAME #######

Time range covered by the visibility predictions:
$ORBITTIME

# All baselines
Sources considered: $OBSERVABLE_SOURCES
Total number of observing options: $OBSERVING_OPPORTUNITIES
Total observing time: $OBSERVING_WINDOWS hours 
Total observing time with Ef: $OBSERVING_WINDOWS_EF hours
Total observing time with Gb: $OBSERVING_WINDOWS_GB hours
Total observing time with At: $OBSERVING_WINDOWS_AT hours

Baselines statistic:
$BASEINE_STATS

# Short baselines <2 ED => good for imaging
Observable sources: $SHORTBASE_OBSERVABLE_SOURCES
Total number of observing options: $SHORTBASE_OBSERVING_OPPORTUNITIES
Total observing time: $SHORTBASE_OBSERVING_WINDOWS hours 
Total observing time with Ef: $SHORTBASE_OBSERVING_WINDOWS_EF hours
Total observing time with Gb: $SHORTBASE_OBSERVING_WINDOWS_GB hours
Total observing time with At: $SHORTBASE_OBSERVING_WINDOWS_AT hours

# Long baselines >25 ED => good for searching extreme Tb
Observable sources: $LONGBASE_OBSERVABLE_SOURCES
Total number of observing options: $LONGBASE_OBSERVING_OPPORTUNITIES
Total observing time: $LONGBASE_OBSERVING_WINDOWS hours 
Total observing time with Ef: $LONGBASE_OBSERVING_WINDOWS_EF hours
Total observing time with Gb: $LONGBASE_OBSERVING_WINDOWS_GB hours
Total observing time with At: $LONGBASE_OBSERVING_WINDOWS_AT hours


 " >> 00_Results.txt

# Plotting and stuff
OBSERVING_OPTIONS=`cat $ORBITRESULTS | grep -e Ef -e Gb -e At | awk '{print $1}' | sort -n |uniq |wc -l`
OBSERVING_OPTIONS_00_02=`cat $ORBITRESULTS | grep -e Ef -e Gb -e At | awk '{if ( $5 <= 2 ) print $1 }' | sort -n |uniq |wc -l`
OBSERVING_OPTIONS_02_04=`cat $ORBITRESULTS | grep -e Ef -e Gb -e At | awk '{if ( $5 > 2 && $5 <=4 ) print $1 }' | sort -n |wc -l`
OBSERVING_OPTIONS_04_06=`cat $ORBITRESULTS | grep -e Ef -e Gb -e At | awk '{if ( $5 > 4 && $5 <=6 ) print $1 }' | sort -n |wc -l`
OBSERVING_OPTIONS_06_08=`cat $ORBITRESULTS | grep -e Ef -e Gb -e At | awk '{if ( $5 > 6 && $5 <=8 ) print $1 }' | sort -n |wc -l`
OBSERVING_OPTIONS_08_10=`cat $ORBITRESULTS | grep -e Ef -e Gb -e At | awk '{if ( $5 > 8 && $5 <=10 ) print $1 }' | sort -n |wc -l`
OBSERVING_OPTIONS_10_12=`cat $ORBITRESULTS | grep -e Ef -e Gb -e At | awk '{if ( $5 > 10 && $5 <=12 ) print $1 }' | sort -n |wc -l`
OBSERVING_OPTIONS_12_14=`cat $ORBITRESULTS | grep -e Ef -e Gb -e At | awk '{if ( $5 > 12 && $5 <=14 ) print $1 }' | sort -n |wc -l`
OBSERVING_OPTIONS_14_16=`cat $ORBITRESULTS | grep -e Ef -e Gb -e At | awk '{if ( $5 > 14 && $5 <=16 ) print $1 }' | sort -n |wc -l`
OBSERVING_OPTIONS_16_18=`cat $ORBITRESULTS | grep -e Ef -e Gb -e At | awk '{if ( $5 > 16 && $5 <=18 ) print $1 }' | sort -n |wc -l`
OBSERVING_OPTIONS_18_20=`cat $ORBITRESULTS | grep -e Ef -e Gb -e At | awk '{if ( $5 > 18 && $5 <=20 ) print $1 }' | sort -n |wc -l`
OBSERVING_OPTIONS_20_22=`cat $ORBITRESULTS | grep -e Ef -e Gb -e At | awk '{if ( $5 > 20 && $5 <=22 ) print $1 }' | sort -n |wc -l`
OBSERVING_OPTIONS_22_24=`cat $ORBITRESULTS | grep -e Ef -e Gb -e At | awk '{if ( $5 > 22 && $5 <=24 ) print $1 }' | sort -n |wc -l`
OBSERVING_OPTIONS_24_26=`cat $ORBITRESULTS | grep -e Ef -e Gb -e At | awk '{if ( $5 > 24 && $5 <=26 ) print $1 }' | sort -n |wc -l`
OBSERVING_OPTIONS_26_28=`cat $ORBITRESULTS | grep -e Ef -e Gb -e At | awk '{if ( $5 > 26 && $5 <=28 ) print $1 }' | sort -n |wc -l`
OBSERVING_OPTIONS_28_20=`cat $ORBITRESULTS | grep -e Ef -e Gb -e At | awk '{if ( $5 > 28 && $5 <=30 ) print $1 }' | sort -n |wc -l`

echo " 1.0 $OBSERVING_OPTIONS_00_02
 3.0 $OBSERVING_OPTIONS_02_04
 5.0 $OBSERVING_OPTIONS_04_06
 7.0 $OBSERVING_OPTIONS_06_08
 9.0 $OBSERVING_OPTIONS_08_10
11.0 $OBSERVING_OPTIONS_10_12
13.0 $OBSERVING_OPTIONS_12_14
15.0 $OBSERVING_OPTIONS_14_16
17.0 $OBSERVING_OPTIONS_16_18
19.0 $OBSERVING_OPTIONS_18_20
21.0 $OBSERVING_OPTIONS_20_22
23.0 $OBSERVING_OPTIONS_22_24
25.0 $OBSERVING_OPTIONS_24_26
27.0 $OBSERVING_OPTIONS_26_28
29.0 $OBSERVING_OPTIONS_28_20
" > observing_options_"$ORBITNAME".dat

#echo "#set encoding koi8r
##set terminal postscript eps enhanced solid \"Arial\" 24 lw 2
#set terminal postscript eps enhanced solid \"Helvetica\" 24 lw 2
#set output \"observing_options_"$ORBITNAME".eps\"
#set title \"Orbit: $ORBITNAME m/s\"
#set xlabel 'B (Earth diameter)'
#set ylabel 'N'
#unset key
#set xrange [0:30]
#set yrange [0:35000]
#set boxwidth 2.0
##set style fill solid border -1
#plot 'observing_options_"$ORBITNAME".dat' with boxes lw 2
#" > observing_options_"$ORBITNAME".gnuplot
#gnuplot observing_options_"$ORBITNAME".gnuplot

LIST_OF_SOURCES=`cat $ORBITRESULTS | awk '{print $4}' | sort | uniq`
for SOURCE in $LIST_OF_SOURCES ;do
  OBSERVING_HOURS=`grep -e "Ef" -e "Gb" -e "At" $ORBITRESULTS | grep "$SOURCE" | awk '{print $1}' | sort -n |uniq |wc -l`
  OBSERVING_HOURS_2ED=`grep -e "Ef" -e "Gb" -e "At" $ORBITRESULTS | grep "$SOURCE" | awk '{if ( $5 < 2 ) print $1 }' | sort -n |uniq |wc -l`
  OBSERVING_HOURS_G25ED=`grep -e "Ef" -e "Gb" -e "At" $ORBITRESULTS | grep "$SOURCE" | awk '{if ( $5 > 25 ) print $1 }' | sort -n |uniq |wc -l`
  START_UNIXSEC=`grep -e "Ef" -e "Gb" -e "At" $ORBITRESULTS | grep "$SOURCE" | awk '{print $1}' | sort -n | head -n1`
  STOP_UNIXSEC=`grep -e "Ef" -e "Gb" -e "At" $ORBITRESULTS | grep "$SOURCE" | awk '{print $1}' | sort -n | tail -n1` 
  START_STR=`LANG=C date -d @$START_UNIXSEC`
  STOP_STR=`LANG=C date -d @$STOP_UNIXSEC`
  MIN_BASELINE=`grep -e "Ef" -e "Gb" -e "At" $ORBITRESULTS | grep "$SOURCE" | awk '{printf "%3d\n",$5*10}' | sort -n | head -n1 | awk '{printf "%4.1lf\n",$1/10}'`
  MAX_BASELINE=`grep -e "Ef" -e "Gb" -e "At" $ORBITRESULTS | grep "$SOURCE" | awk '{printf "%3d\n",$5*10}' | sort -n | tail -n1 | awk '{printf "%4.1lf\n",$1/10}'`
  echo "_____ $SOURCE _____
Observable between $START_STR and $STOP_STR
Observing hours: $OBSERVING_HOURS (total), $OBSERVING_HOURS_2ED (baseline < 2 ED), $OBSERVING_HOURS_G25ED (baseline > 25 ED)
Baseline range: $MIN_BASELINE -- $MAX_BASELINE ED
" >> 00_Results.txt

#grep -e "Ef" -e "Gb" -e "At" $ORBITRESULTS | grep "$SOURCE" | awk '{print $6"  "$5"  "$1" "$2" "$3}' > uvplot_"$ORBITNAME"_$SOURCE.dat
grep -e "Ef" -e "Gb" -e "At" $ORBITRESULTS | grep "$SOURCE" | awk '{printf "%5.1f  %4.1f  %s  %s %s\n",$6,$5,$1,$2,$3}' > uvplot_"$ORBITNAME"_$SOURCE.dat

echo "#set encoding koi8r
#set terminal postscript eps enhanced solid \"Arial\" 20 lw 2
set terminal postscript eps enhanced solid \"Helvetica\" 20 lw 2
set output \"uvplot_"$ORBITNAME"_$SOURCE.eps\"
# 'noenhanced' parameter will make the underscore '_' display correctly in this string
set title \"$SOURCE\" noenhanced
set xlabel 'U (Earth diameter)'
set ylabel 'V (Earth diameter)'
unset key
set polar
set angles degrees
set size square
set xrange [30:-30]
set yrange [-30:30]
set xtics (\"30\" 30, \"20\" 20, \"10\" 10, \"0\" 0, \"-10\" -10, \"-20\" -20, \"-30\" -30)
set ytics (\"-30\" -30, \"-20\" -20, \"-10\" -10, \"0\" 0, \"10\" 10, \"20\" 20, \"30\" 30)
unset raxis
unset rtics
plot \"uvplot_"$ORBITNAME"_$SOURCE.dat\" u 1:2 lt 1 lc 'black' pt 7 ps 0.3 title '', \"uvplot_"$ORBITNAME"_$SOURCE.dat\" u 1:(-1*\$2) lt 1 lc 'black' pt 7 ps 0.3 title ''
! convert  -density 150  \"uvplot_"$ORBITNAME"_$SOURCE.eps\"   -background white -alpha remove  \"uvplot_"$ORBITNAME"_$SOURCE.png\"
" > uvplot_"$ORBITNAME"_$SOURCE.gnuplot
gnuplot uvplot_"$ORBITNAME"_$SOURCE.gnuplot


done # for SOURCE in 

 echo "
 
 " >> 00_Results.txt

done # for ORBITRESULTS in ...


echo "
Things to keep in mind while interpreting the results:
* Observing options are \"observing hour - source\" combinations. Many observing options typically correspond to a given hour.
* The number of observing hours is taking into account only the visibility constraints, but no thermal constraints.
" >> 00_Results.txt

echo "

"

cat 00_Results.txt

